==> jc-1.4.0.tar.gz: javax/swing/tree/DefaultTreeCellEditor__24DefaultTextField.h <==
// public class javax.swing.tree.DefaultTreeCellEditor$DefaultTextField

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 86a3257a189ec71a javax_swing_JTextField
// @dep_class ed5ab5d42432ac7 javax_swing_text_JTextComponent
// @dep_class 961b8bb7c5abac87 javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField

// header file dependencies
// @dep_header javax_swing_JTextField

#include "javax/swing/JTextField.h"

#ifndef _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_
#define _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_tree_DefaultTreeCellEditor$object;

// Typedefs
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object;

typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype;

// Constructors
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$_init$0ffcabd7df7d5cfe(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *, struct _jc_javax_swing_tree_DefaultTreeCellEditor$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getBorder$97a4d647b755be10(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);
extern struct _jc_java_awt_Font$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getFont$19a1c5a972cac1da(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getBorder$97a4d647b755be10;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getFont$19a1c5a972cac1da;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods {
	struct _jc_object	*(*getBorder$97a4d647b755be10)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);
	struct _jc_java_awt_Font$object	*(*getFont$19a1c5a972cac1da)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *);
};

// Vtable
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_text_JTextComponent$vmethods	javax_swing_text_JTextComponent;
	_jc_javax_swing_JTextField$vmethods	javax_swing_JTextField;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
};

// Vtype
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs {
	struct _jc_object	*border;
	struct _jc_javax_swing_tree_DefaultTreeCellEditor$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs {
    _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
    _jc_javax_swing_JTextField$sub_refs	javax_swing_JTextField;
    _jc_javax_swing_text_JTextComponent$sub_refs	javax_swing_text_JTextComponent;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_text_JTextComponent$sub_nonrefs	javax_swing_text_JTextComponent;
    _jc_javax_swing_JTextField$sub_nonrefs	javax_swing_JTextField;
    _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
};

// Object instance structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object {
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype	*vtype;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$class_object;

#endif	/* _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_ */

==> jc-1.4.5.tar.gz: javax/swing/tree/DefaultTreeCellEditor__24DefaultTextField.h <==
// public class javax.swing.tree.DefaultTreeCellEditor$DefaultTextField

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 86a3257a189ec71a javax_swing_JTextField
// @dep_class 2c925603dda7f75 javax_swing_text_JTextComponent
// @dep_class 961b8bb7c5abac87 javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField

// header file dependencies
// @dep_header javax_swing_JTextField

#include "javax/swing/JTextField.h"

#ifndef _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_
#define _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_tree_DefaultTreeCellEditor$object;

// Typedefs
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs;
typedef struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object;

typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable;
typedef const struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype;

// Constructors
extern void _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$_init$0ffcabd7df7d5cfe(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *, struct _jc_javax_swing_tree_DefaultTreeCellEditor$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getBorder$97a4d647b755be10(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Font$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getFont$19a1c5a972cac1da(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getBorder$97a4d647b755be10;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getFont$19a1c5a972cac1da;
extern _jc_method _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$method_info$getPreferredSize$4730bc91c97b24d9;

// Virtual methods structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods {
	struct _jc_object	*(*getBorder$97a4d647b755be10)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Font$object	*(*getFont$19a1c5a972cac1da)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_text_JTextComponent$vmethods	javax_swing_text_JTextComponent;
	_jc_javax_swing_JTextField$vmethods	javax_swing_JTextField;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vmethods	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
};

// Vtype
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs {
	struct _jc_object	*border;
	struct _jc_javax_swing_tree_DefaultTreeCellEditor$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs {
    _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_refs	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
    _jc_javax_swing_JTextField$sub_refs	javax_swing_JTextField;
    _jc_javax_swing_text_JTextComponent$sub_refs	javax_swing_text_JTextComponent;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_text_JTextComponent$sub_nonrefs	javax_swing_text_JTextComponent;
    _jc_javax_swing_JTextField$sub_nonrefs	javax_swing_JTextField;
    _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$sub_nonrefs	javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField;
};

// Object instance structure
struct _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$object {
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype	*vtype;
	_jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$vtype _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField$class_object;

#endif	/* _JC_javax_swing_tree_DefaultTreeCellEditor__24DefaultTextField_H_ */
